/*
**   Copyright (c) Steven G. Judd 1992, 1993, 1994
**		       All Rights Reserved.
**
** Unpublished rights reserved  under the copyright laws of the
** United States.
**++
**
** FACILITY      : Message Queues
** MODULE NAME   : mq_public.h
**
** ABSTRACT      : MQ public definitions (Windows NT)
**
** AUTHOR        : Steven G. Judd
** CREATION DATE : 28-Nov-1992
**
** MODIFICATION HISTORY :
**
** X-5 sgj0007  30-apr-1994 timeouts
** X-4 sgj0004  24-apr-1994 Add Info routines
** X-3 sgj0003	23-apr-1994	Add MqCancel routines
** X-2 sgj0002	23-apr-1994	Add symbols for blocking / nonblocking
*/

#ifndef _MQ_PUBLIC
#define _MQ_PUBLIC 1

#include <windows.h>

/*-------------- Define symbols for code clarity ------------------*/

#define MQ_BLOCKING    TRUE
#define MQ_NONBLOCKING FALSE
#define MQ_TYPE_ANY    0

/*-------------- Structure types for Info routines ----------------*/

typedef struct _MqGlobalInfo {
					long	max_q;			   // maximum number of queues
					long	max_msg;		   // maximum number of messages
					long	max_msg_size;	   // maximum size of message
					long	max_seg;		   // number of message segments
					long	seg_size;          // size of a message segment
					long	free_msg;		   // number of free messages
					long	free_seg;		   // number of free segments
					long	free_q;			   // number of free queues
					long	wait_msg_count;	   // number of clients blocked for a free message
					long	wait_seg_count;	   // number of clients blocked for a free segment
               } MqGlobalInfo;

typedef struct _MqQueueInfo {
					long	attach_count;      // number of clients that have this queue attached
					long    msg_count;         // number of messages in this queue
					long    wait_count;        // number of clients blocked waiting for a message
					BOOL	destroy;           // queue is marked for removal from system;
					char    q_name[255];       // name of this queue
               } MqQueueInfo;

/*-------------------- Function Prototypes ------------------------*/

typedef void *HMQ;

long
MqCreate(HMQ *,char *);

long
MqAttach(HMQ *,char *);

long
MqDetach(HMQ);

long
MqDestroy(HMQ);

long
MqPut(HMQ ,char *,long, long, BOOL, ULONG);

long
MqGet(HMQ, long, long *, char *, long, long *, BOOL, ULONG);

long
MqCancelGet(HMQ);

long
MqCancelPut(HMQ);

long
MqGetGlobalInfo(MqGlobalInfo *);

long
MqGetQInfo(HMQ,MqQueueInfo *);

long
MqEnumQ(void (*)(char *));

#endif

